@@ -6,17 +6,44 @@ use crate::error::SparseLinearAlgebraError;
 use crate::operators::{
     binary_operator::BinaryOperator, mask::VectorMask, options::OperatorOptions,
 };
-use crate::sparse_matrix::SparseMatrix;
-use crate::sparse_vector::SparseVector;
 use crate::util::{
     ElementIndex, ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion,
 };
-use crate::value_type::{AsBoolean, ValueType};
+use crate::value_types::sparse_matrix::SparseMatrix;
+use crate::value_types::sparse_vector::SparseVector;
+use crate::value_types::value_type::{AsBoolean, ValueType};
 
 use crate::bindings_to_graphblas_implementation::{GrB_BinaryOp, GrB_Col_assign, GrB_Descriptor};
 
 // TODO: explicitly define how dupicates are handled
 
+// Implemented methods do not provide mutable access to GraphBLAS operators or options.
+// Code review must consider that no mtable access is provided.
+// https://doc.rust-lang.org/nomicon/send-and-sync.html
+unsafe impl Send for InsertVectorIntoColumn<bool, bool> {}
+unsafe impl Send for InsertVectorIntoColumn<u8, u8> {}
+unsafe impl Send for InsertVectorIntoColumn<u16, u16> {}
+unsafe impl Send for InsertVectorIntoColumn<u32, u32> {}
+unsafe impl Send for InsertVectorIntoColumn<u64, u64> {}
+unsafe impl Send for InsertVectorIntoColumn<i8, i8> {}
+unsafe impl Send for InsertVectorIntoColumn<i16, i16> {}
+unsafe impl Send for InsertVectorIntoColumn<i32, i32> {}
+unsafe impl Send for InsertVectorIntoColumn<i64, i64> {}
+unsafe impl Send for InsertVectorIntoColumn<f32, f32> {}
+unsafe impl Send for InsertVectorIntoColumn<f64, f64> {}
+
+unsafe impl Sync for InsertVectorIntoColumn<bool, bool> {}
+unsafe impl Sync for InsertVectorIntoColumn<u8, u8> {}
+unsafe impl Sync for InsertVectorIntoColumn<u16, u16> {}
+unsafe impl Sync for InsertVectorIntoColumn<u32, u32> {}
+unsafe impl Sync for InsertVectorIntoColumn<u64, u64> {}
+unsafe impl Sync for InsertVectorIntoColumn<i8, i8> {}
+unsafe impl Sync for InsertVectorIntoColumn<i16, i16> {}
+unsafe impl Sync for InsertVectorIntoColumn<i32, i32> {}
+unsafe impl Sync for InsertVectorIntoColumn<i64, i64> {}
+unsafe impl Sync for InsertVectorIntoColumn<f32, f32> {}
+unsafe impl Sync for InsertVectorIntoColumn<f64, f64> {}
+
 #[derive(Debug, Clone)]
 pub struct InsertVectorIntoColumn<MatrixToInsertInto: ValueType, VectorToInsert: ValueType> {
     _matrix_to_insert_into: PhantomData<MatrixToInsertInto>,
@@ -219,10 +246,10 @@ mod tests {
     use crate::context::{Context, Mode};
     use crate::operators::binary_operator::First;
 
-    use crate::sparse_matrix::{
+    use crate::value_types::sparse_matrix::{
         FromMatrixElementList, GetMatrixElementValue, MatrixElementList, Size,
     };
-    use crate::sparse_vector::{FromVectorElementList, VectorElementList};
+    use crate::value_types::sparse_vector::{FromVectorElementList, VectorElementList};
 
     #[test]
     fn test_insert_vector_into_column() {
